==> jc-1.4.0.tar.gz: gnu/java/beans/DoubleKey.h <==
// class gnu.java.beans.DoubleKey

// class file dependencies
// @dep_class 66855ddf20e6e059 gnu_java_beans_DoubleKey
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_beans_DoubleKey_H_
#define _JC_gnu_java_beans_DoubleKey_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_DoubleKey$sub_refs	_jc_gnu_java_beans_DoubleKey$sub_refs;
typedef struct _jc_gnu_java_beans_DoubleKey$sub_nonrefs	_jc_gnu_java_beans_DoubleKey$sub_nonrefs;
typedef struct _jc_gnu_java_beans_DoubleKey$refs	_jc_gnu_java_beans_DoubleKey$refs;
typedef struct _jc_gnu_java_beans_DoubleKey$nonrefs	_jc_gnu_java_beans_DoubleKey$nonrefs;
typedef struct _jc_gnu_java_beans_DoubleKey$object	_jc_gnu_java_beans_DoubleKey$object;

typedef const struct _jc_gnu_java_beans_DoubleKey$vmethods	_jc_gnu_java_beans_DoubleKey$vmethods;
typedef const struct _jc_gnu_java_beans_DoubleKey$vtable	_jc_gnu_java_beans_DoubleKey$vtable;
typedef const struct _jc_gnu_java_beans_DoubleKey$vtype	_jc_gnu_java_beans_DoubleKey$vtype;

// Constructors
extern void _jc_gnu_java_beans_DoubleKey$method$_init$ac0e52b006af8a7c(_jc_env *, struct _jc_gnu_java_beans_DoubleKey$object *, struct _jc_java_lang_Class$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern jboolean _jc_gnu_java_beans_DoubleKey$method$equals$8a15e0625571c581(_jc_env *, struct _jc_gnu_java_beans_DoubleKey$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_beans_DoubleKey$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_gnu_java_beans_DoubleKey$object *);
extern struct _jc_java_lang_Class$object *_jc_gnu_java_beans_DoubleKey$method$getType$817b56efb070d60a(_jc_env *, struct _jc_gnu_java_beans_DoubleKey$object *);
extern jint _jc_gnu_java_beans_DoubleKey$method$hashCode$53152098849316df(_jc_env *, struct _jc_gnu_java_beans_DoubleKey$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_DoubleKey$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_gnu_java_beans_DoubleKey$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_gnu_java_beans_DoubleKey$method_info$getType$817b56efb070d60a;
extern _jc_method _jc_gnu_java_beans_DoubleKey$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_gnu_java_beans_DoubleKey$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_gnu_java_beans_DoubleKey$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_gnu_java_beans_DoubleKey$object *);
	struct _jc_java_lang_Class$object	*(*getType$817b56efb070d60a)(_jc_env *, struct _jc_gnu_java_beans_DoubleKey$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_gnu_java_beans_DoubleKey$object *);
};

// Vtable
struct _jc_gnu_java_beans_DoubleKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_DoubleKey$vmethods	gnu_java_beans_DoubleKey;
};

// Vtype
struct _jc_gnu_java_beans_DoubleKey$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_DoubleKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_DoubleKey$sub_refs {
	struct _jc_java_lang_Class$object	*type;
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_DoubleKey$refs {
    _jc_gnu_java_beans_DoubleKey$sub_refs	gnu_java_beans_DoubleKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_DoubleKey$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_DoubleKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_DoubleKey$sub_nonrefs	gnu_java_beans_DoubleKey;
};

// Object instance structure
struct _jc_gnu_java_beans_DoubleKey$object {
	_jc_gnu_java_beans_DoubleKey$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_DoubleKey$vtype	*vtype;
	_jc_gnu_java_beans_DoubleKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_DoubleKey$vtype _jc_gnu_java_beans_DoubleKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_DoubleKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_DoubleKey$class_object;

#endif	/* _JC_gnu_java_beans_DoubleKey_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/DoubleKey.h <==
// class gnu.java.beans.DoubleKey

// class file dependencies
// @dep_class f180f0ea9542de81 gnu_java_beans_DoubleKey
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_beans_DoubleKey_H_
#define _JC_gnu_java_beans_DoubleKey_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_DoubleKey$sub_refs	_jc_gnu_java_beans_DoubleKey$sub_refs;
typedef struct _jc_gnu_java_beans_DoubleKey$sub_nonrefs	_jc_gnu_java_beans_DoubleKey$sub_nonrefs;
typedef struct _jc_gnu_java_beans_DoubleKey$refs	_jc_gnu_java_beans_DoubleKey$refs;
typedef struct _jc_gnu_java_beans_DoubleKey$nonrefs	_jc_gnu_java_beans_DoubleKey$nonrefs;
typedef struct _jc_gnu_java_beans_DoubleKey$object	_jc_gnu_java_beans_DoubleKey$object;

typedef const struct _jc_gnu_java_beans_DoubleKey$vmethods	_jc_gnu_java_beans_DoubleKey$vmethods;
typedef const struct _jc_gnu_java_beans_DoubleKey$vtable	_jc_gnu_java_beans_DoubleKey$vtable;
typedef const struct _jc_gnu_java_beans_DoubleKey$vtype	_jc_gnu_java_beans_DoubleKey$vtype;

// Constructors
extern void _jc_gnu_java_beans_DoubleKey$method$_init$ac0e52b006af8a7c(_jc_env *, struct _jc_gnu_java_beans_DoubleKey$object *, struct _jc_java_lang_Class$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_gnu_java_beans_DoubleKey$method$equals$8a15e0625571c581(_jc_env *, struct _jc_gnu_java_beans_DoubleKey$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_beans_DoubleKey$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_gnu_java_beans_DoubleKey$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_gnu_java_beans_DoubleKey$method$getType$817b56efb070d60a(_jc_env *, struct _jc_gnu_java_beans_DoubleKey$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_beans_DoubleKey$method$hashCode$53152098849316df(_jc_env *, struct _jc_gnu_java_beans_DoubleKey$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_DoubleKey$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_gnu_java_beans_DoubleKey$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_gnu_java_beans_DoubleKey$method_info$getType$817b56efb070d60a;
extern _jc_method _jc_gnu_java_beans_DoubleKey$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_gnu_java_beans_DoubleKey$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_gnu_java_beans_DoubleKey$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_gnu_java_beans_DoubleKey$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Class$object	*(*getType$817b56efb070d60a)(_jc_env *, struct _jc_gnu_java_beans_DoubleKey$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_gnu_java_beans_DoubleKey$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_DoubleKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_DoubleKey$vmethods	gnu_java_beans_DoubleKey;
};

// Vtype
struct _jc_gnu_java_beans_DoubleKey$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_DoubleKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_DoubleKey$sub_refs {
	struct _jc_java_lang_Class$object	*type;
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_DoubleKey$refs {
    _jc_gnu_java_beans_DoubleKey$sub_refs	gnu_java_beans_DoubleKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_DoubleKey$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_DoubleKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_DoubleKey$sub_nonrefs	gnu_java_beans_DoubleKey;
};

// Object instance structure
struct _jc_gnu_java_beans_DoubleKey$object {
	_jc_gnu_java_beans_DoubleKey$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_DoubleKey$vtype	*vtype;
	_jc_gnu_java_beans_DoubleKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_DoubleKey$vtype _jc_gnu_java_beans_DoubleKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_DoubleKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_DoubleKey$class_object;

#endif	/* _JC_gnu_java_beans_DoubleKey_H_ */
